# Eopsin

[![Test](https://github.com/cxkoda/plutus/workflows/Test/badge.svg)](https://github.com/cxkoda/plutus/actions)
[![CodeQL](https://github.com/cxkoda/plutus/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/cxkoda/plutus/actions/workflows/codeql-analysis.yml)

Yet another automated crypto trading framework featuring a flexible strategy backtesting and automatic caching of exchange data in a local database.